--[[
The Broken Mirror Augment Swapper v0.6 by MrInfernal

ToDo:
Weapon augs

Note: 
Plane of Health merchants:
Weapon Augs: Shirlell Isnamgam

]]

---@type Mq
local mq = require('mq')
---@type ImGui
local imgui = require 'ImGui'

local myLevel = mq.TLO.Me.Level()
local myClass = mq.TLO.Me.Class.ShortName()
RoT = mq.TLO.Me.AltCurrency('Remnants of Tranquility')()
local augPrefixIndex = 1 -- For aug level
local type5Index = 1
local type9Index = 1
local sellOldAugs = true
local priestClass = {'DRU', 'SHM', 'CLR'}
local casterClass = {'ENC', 'MAG', 'NEC', 'WIZ'}
local meleeClass = {'BER', 'MNK', 'ROG'}
local hybridClass = {'BRD', 'RNG', 'BST'}
local doVis = true
local doNonVis = false
--local doWep = false
local doDebug = true
local myClassGroup = 'Tank' -- Default value. WAR, PAL, and SHD

for _, class in ipairs(priestClass) do
    if class == myClass then
        myClassGroup = 'Priest'
    end
end

for _, class in ipairs(casterClass) do
    if class == myClass then
        myClassGroup = 'Caster'
    end
end

for _, class in ipairs(meleeClass) do
    if class == myClass then
        myClassGroup = 'Melee'
    end
end

for _, class in ipairs(hybridClass) do
    if class == myClass then
        myClassGroup = 'Hybrid'
    end
end

local augPrefix = {
    '75: Elegant',
    '80: Stalwart',
    '85: Extravagant',
    '90: Glorious',
    '95: Regal',
    '100: August',
    '105: Resplendent'
}

local type5Suffix = {
    'Stability: All', --1
    'Courage: STR',
    'Resilience: STA',
    'Deftness: DEX', --4
    'Swiftness: AGI',
    'Scholarship: INT',
    'Foresight: WIS',
    'Allure: CHA' --8
}

local type9Suffix = {
    'Fulcrum: All', --1
    'Sturdy: +AC - Less HP/Mana',
    'Valiant: +HP - Less Mana', --3
    'Resourceful: +Mana - Less HP',
    'Beneficent: +Heal',
    'Vengeful: +Spell DMG - +Attack', --6
}

-- Set default type 9 according to Almar's Guide
if myClassGroup == 'Hybrid' or myClassGroup == 'Caster' then
    type9Index = 4
elseif myClassGroup == 'Melee' then
    type9Index = 6
elseif myClassGroup == 'Priest' then
    type9Index = 3
elseif myClassGroup == 'Tank' then
    type9Index = 2
end

-- Set aug level and change type 9 if needed
if myLevel >= 75 then
    augPrefixIndex = 1
elseif myLevel >= 80 and myLevel <= 84 then
    augPrefixIndex = 2
elseif myLevel >= 85 and myLevel <= 89 then
    augPrefixIndex = 3
elseif myLevel >= 90 and myLevel <= 94 then
    augPrefixIndex = 4
elseif myLevel >= 95 and myLevel <= 99 then
    augPrefixIndex = 5
elseif myLevel >= 100 and myLevel <= 104 then
    augPrefixIndex = 6
    if myClassGroup == 'Caster' or myClassGroup == 'Hybrid' then
        type9Index = 4
    end
elseif myLevel >= 105 then
    augPrefixIndex = 7
    if myClassGroup == 'Melee' then
        type9Index = 1
    elseif myClassGroup == 'Caster' then
        type9Index = 6
    elseif myClassGroup == 'Priest' then
        type9Index = 5
    end
end

local gearSlotVis = {
    'head', -- 1
    'arms',
    'leftwrist',
    'rightwrist',
    'hands',  -- 5
    'chest',
    'legs',
    'feet',  -- 8
}

local gearSlotNonVis = {
    'leftear', -- 1
    'rightear',
    'face',
    'neck',
    'shoulder',  -- 5
    'back',
    'leftfinger',
    'rightfinger',
    'waist',
    'charm',  -- 10
}

local gearSlotWep = {
    'mainhand',
    'offhand',
    'ranged'
}

VisGear = {}
NonVisGear = {}
WepGear = {}

-- Create tables for different gear types
for _, slot in ipairs(gearSlotVis) do
    table.insert(VisGear, mq.TLO.Me.Inventory(slot))
end

for _, slot in ipairs(gearSlotNonVis) do
    table.insert(NonVisGear, mq.TLO.Me.Inventory(slot))
end

for _, slot in ipairs(gearSlotWep) do
    table.insert(WepGear, mq.TLO.Me.Inventory(slot))
end

-- Get combobox values to construct aug name
local function getAugName(type, level, suffix)
    local augName = ''

    local prefix = {
        'Elegant', -- 1
        'Stalwart',
        'Extravagant',
        'Glorious', -- 4
        'Regal',
        'August',
        'Resplendent' -- 7
    }
    
    local suffix5 = {
        'Stability', --1
        'Courage',
        'Resilience',
        'Deftness', --4
        'Swiftness',
        'Scholarship',
        'Foresight',
        'Allure' --8
    }

    local suffix9 = {
        'the Fulcrum', --1
        'the Sturdy',
        'the Valiant', --3
        'the Resourceful',
        'the Beneficent',
        'the Vengeful', --6
    }

    if type == 5 then
        augName = prefix[level] .. ' Sulstone of ' .. suffix5[suffix]
    elseif type == 9 then
        augName = prefix[level] .. ' Sulstone of ' .. suffix9[suffix]
    end

    return augName
end

-- Check gear for available aug slots
-- Will check if proper type and if already slotted
local function countAugs(gearTable, type, level, suffix)

    local count = 0
    local cost = 0
    local solvCount = 0
    local name = getAugName(type, level, suffix)
    local gearForAugs = {}
    local removedAugs = {}

    --[['weps' 
        1h/shield: aug2: 5, aug4: 9
           2h:     aug3: 5, aug5: 9]]

    for _, gear in ipairs(VisGear) do
        if gearTable == 'armor' and doVis then
            if type == 5 then
                if (gear.AugSlot(1).Empty() or gear.AugSlot(1).Name() ~= name) and gear.AugSlot(1).Type() == 5 then
                    count = count + 1
                    table.insert(gearForAugs, gear)
                    if not gear.AugSlot(1).Empty() then
                        table.insert(removedAugs, gear.AugSlot(1).Name())
                        solvCount = solvCount + 1
                    end
                end
            elseif type == 9 then
                if (gear.AugSlot(3).Empty() or gear.AugSlot(3).Name() ~= name) and gear.AugSlot(3).Type() == 9 then
                    count = count + 1
                    table.insert(gearForAugs, gear)
                    if not gear.AugSlot(3).Empty() then
                        table.insert(removedAugs, gear.AugSlot(3).Name())
                        solvCount = solvCount + 1
                    end
                end
            end
        end
    end

    for _, gear in ipairs(NonVisGear) do
        if gearTable == 'armor' and doNonVis then
            if type == 5 then
                if (gear.AugSlot(1).Empty() or gear.AugSlot(2).Name() ~= name) and gear.AugSlot(2).Type() == 5 then
                    count = count + 1
                    table.insert(gearForAugs, gear)
                    if not gear.AugSlot(2).Empty() then
                        table.insert(removedAugs, gear.AugSlot(2).Name())
                        solvCount = solvCount + 1
                    end
                end
            elseif type == 9 then
                if (gear.AugSlot(4).Empty() or gear.AugSlot(4).Name() ~= name) and gear.AugSlot(4).Type() == 9 then
                    count = count + 1
                    table.insert(gearForAugs, gear)
                    if not gear.AugSlot(4).Empty() then
                        table.insert(removedAugs, gear.AugSlot(4).Name())
                        solvCount = solvCount + 1
                    end
                end
            end
        end
    end

    if level == 1 then
        cost = count * 50
    elseif level == 2 then
        cost = count * 90
    elseif level == 3 then
        cost = count * 190
    elseif level == 4 then
        cost = count * 380
    elseif level == 5 then
        cost = count * 630
    elseif level == 6 then
        cost = count * 940
    elseif level == 7 then
        cost = count * 1250
    end

    return count, name, cost, solvCount, gearForAugs, removedAugs
end

-- Allow checking count and cost of requested aug
local function checkAugs(gearTable, type, level, suffix)

    local count, name, cost, gearForAugs, removedAugs = countAugs(gearTable, type, level, suffix)

    if count == 0 then
        printf('No slots found for %s.\nEnsure that you have type %d slots.', name, type)
    else
        printf('Need to purchase \at%d \ao%s \ax\ax\axfor \at%d \axRemnants.', count, name, cost)
    end
end

local function doAugs(gearTable, type, level, suffix)
    local myLevel = mq.TLO.Me.Level()
    local levelCheck = true

    --Get a count and cost of the augs
    local count, name, cost, solvCount, gearForAugs, removedAugs = countAugs(gearTable, type, level, suffix)
    local invCheck = 0
    local solvCheck = 0

    local stop = false
    Delay = 25

    -- Check if high enough level for selected augs
    if level == 1 and myLevel < 75 then
        levelCheck = false
    elseif level == 2 and myLevel < 80 then
        levelCheck = false
    elseif level == 3 and myLevel < 85 then
        levelCheck = false
    elseif level == 4 and myLevel < 90 then
        levelCheck = false
    elseif level == 5 and myLevel < 95 then
        levelCheck = false
    elseif level == 6 and myLevel < 100 then
        levelCheck = false
    elseif level == 7 and myLevel < 105 then
        levelCheck = false
    end

    if not levelCheck then
        printf('Level too low for %s!', name)
        stop = true
    end

    if not doVis and not doNonVis then
        print('No Armor boxes checked! Choose Visible, Nonvisible, or both.')
        stop = true
    end

    if mq.TLO.Zone.ShortName() ~= 'pohealth' and not doDebug then
        print('\arNot in Plane of Health!')
        stop = true
    end

    if not stop then
        -- Set the solvent to use
        local solvent = 'Class X Augmentation Distiller'
        local solvCost = 30

        if level == 2 then
            solvent = 'Class XI Augmentation Distiller'
            solvCost = 45
        elseif level == 3 then
            solvent = 'Class XII Augmentation Distiller'
            solvCost = 55
        elseif level == 4 then
            solvent = 'Class XIII Augmentation Distiller'
            solvCost = 70
        elseif level == 5 then
            solvent = 'Class XIV Augmentation Distiller'
            solvCost = 85
        elseif level == 6 then
            solvent = 'Class XV Augmentation Distiller'
            solvCost = 110
        elseif level == 7 then
            solvent = 'Class XVI Augmentation Distiller'
            solvCost = 135
        end

        -- See if need to buy augs
        if mq.TLO.FindItemCount(name)() > 0 then
            invCheck = mq.TLO.FindItemCount(name)()
            count = count - invCheck
            if doDebug then
                printf('\agDebug: \axWill need to buy \at%d \ao%s for \ay%d remnants', count, name, cost)
            end
        end

        -- See if solvents needed
        if mq.TLO.FindItemCount(solvent)() >0 then
            solvCheck = mq.TLO.FindItemCount(solvent)()
            solvCount = solvCount - solvCheck
            if mq.TLO.FindItemCount('Perfected Augmentation Distiller')() >0 then
                solvCheck = mq.TLO.FindItemCount('Perfected Augmentation Distiller')()
                solvCount = solvCount - solvCheck
            end
        else
            solvCost = solvCost * solvCount
        end

        -- Buy distillers if needed
        if solvCount >0 then
            if doDebug then
                if mq.TLO.Me.Cash()/1000 > solvCost then
                    if not mq.TLO.Merchant.Open() then
                        mq.cmdf('/timed %d /echo \agDebug: \axNeed to purchase \at%d \ao%s \axfor \at%d \axpp!', Delay, solvCount, solvent, solvCost)
                        Delay = Delay + 3
                        mq.cmdf('/timed %d /echo \agDebug: \axOpen Dabowe\'s merchant window', Delay)
                        Delay = Delay + 15
                        mq.cmdf('/timed %d /echo \agDebug: \axBuy \at%d \ao%s\n', Delay, solvCount, solvent, solvCost)
                        Delay = Delay + 5
                    end
                else
                    printf('\arError! \ax%d %s costs %d! You need %d more!', solvCount, solvent, solvCost, solvCost - mq.TLO.Me.Cash()/1000)
                end
            else
                if mq.TLO.Me.Cash()/1000 > solvCost then
                    if not mq.TLO.Merchant.Open() then
                        mq.cmdf('/timed %d /tar Dabowe', Delay)
                        Delay = Delay + 2
                        mq.cmdf('/timed %d /invoke ${Merchant.OpenWindow}', Delay)
                        Delay = Delay + 3
                    end
                    mq.cmdf('/timed %d /echo Need to purchase \at%d \ao%s \axfor \at%d \axpp!', Delay, solvCount, solvent, solvCost)
                    Delay = Delay + 15

                    mq.cmdf('/timed %d /invoke ${Merchant.SelectItem[=%d]}', Delay, solvent)
                    Delay = Delay + 10
                    mq.cmdf('/timed %d /invoke ${Merchant.Buy[%d]}', Delay, solvCount)
                    Delay = Delay + 10
                    mq.cmdf('/timed %d /notify MerchantWnd MW_Done_Button leftmouseup', Delay)
                    Delay = Delay + 15
                else
                    printf('\arError! \ax%d %s costs %d! You need %d more!', solvCount, solvent, solvCost, solvCost - mq.TLO.Me.Cash()/1000)
                end
            end
        end

        -- Remove augs from gear
        if doDebug then
            if #removedAugs > 0 then
                mq.cmdf('/timed %d /echo Removing old augs from gear!', Delay)
                Delay = Delay + 5
            end
            for _, gear in ipairs(gearForAugs) do
                if not gear.AugSlot(1).Empty() then
                    if gear.AugSlot(1).Type() == 5 then
                        mq.cmdf('/timed %d /echo \agDebug: \axRemove \ao"%s" \axfrom \ao"%s"', Delay, gear.AugSlot(1).Name(), gear)
                        Delay = Delay + 5
                    end
                elseif not gear.AugSlot(3).Empty() then
                    if gear.AugSlot(3).Type() == 5 then
                        mq.cmdf('/timed %d /echo \agDebug: \axRemove \ao"%s" \axfrom \ao"%s"', Delay, gear.AugSlot(3).Name(), gear)
                        Delay = Delay + 5
                    end
                elseif not gear.AugSlot(2).Empty() then
                    if gear.AugSlot(2).Type() == 9 then
                        mq.cmdf('/timed %d /echo \agDebug: \axRemove \ao"%s" \axfrom \ao"%s"', Delay, gear.AugSlot(2).Name(), gear)
                        Delay = Delay + 5
                    end
                elseif not gear.AugSlot(4).Empty() then
                    if gear.AugSlot(4).Type() == 9 then
                        mq.cmdf('/timed %d /echo \agDebug: \axRemove \ao"%s" \axfrom \ao"%s"', Delay, gear.AugSlot(4).Name(), gear)
                        Delay = Delay + 5
                    end
                end
            end
        else
            if #removedAugs > 0 then
                mq.cmdf('/timed %d /echo Removing old augs from gear!\n', Delay)
                Delay = Delay + 5
            end
            for _, gear in ipairs(gearForAugs) do
                if not gear.AugSlot(1).Empty() then
                    if gear.AugSlot(1).Type() == 5 then
                        mq.cmdf('/timed %d /removeaug "%s" "%s"', Delay, gear.AugSlot(1).Name(), gear)
                        Delay = Delay + 10
                        mq.cmdf('/timed %d /if (${Window[ConfirmationDialogBox].Open}) /nomodkey /notify ConfirmationDialogBox Yes_Button leftmouseup', Delay)
                        Delay = Delay + 10
                        mq.cmdf('/timed %d /autoinventory', Delay)
                        Delay = Delay + 10
                    end
                elseif not gear.AugSlot(3).Empty() then
                    if gear.AugSlot(3).Type() == 5 then
                        mq.cmdf('/timed %d /removeaug "%s" "%s"', Delay, gear.AugSlot(2).Name(), gear)
                        Delay = Delay + 10
                        mq.cmdf('/timed %d /if (${Window[ConfirmationDialogBox].Open}) /nomodkey /notify ConfirmationDialogBox Yes_Button leftmouseup', Delay)
                        Delay = Delay + 10
                        mq.cmdf('/timed %d /autoinventory', Delay)
                        Delay = Delay + 10
                    end
                elseif not gear.AugSlot(2).Empty() then
                    if gear.AugSlot(2).Type() == 9 then
                        mq.cmdf('/timed %d /removeaug "%s" "%s"', Delay, gear.AugSlot(3).Name(), gear)
                        Delay = Delay + 10
                        mq.cmdf('/timed %d /if (${Window[ConfirmationDialogBox].Open}) /nomodkey /notify ConfirmationDialogBox Yes_Button leftmouseup', Delay)
                        Delay = Delay + 10
                        mq.cmdf('/timed %d /autoinventory', Delay)
                        Delay = Delay + 10
                    end
                elseif not gear.AugSlot(4).Empty() then
                    if gear.AugSlot(4).Type() == 9 then
                        mq.cmdf('/timed %d /removeaug "%s" "%s"', Delay, gear.AugSlot(4).Name(), gear)
                        Delay = Delay + 10
                        mq.cmdf('/timed %d /if (${Window[ConfirmationDialogBox].Open}) /nomodkey /notify ConfirmationDialogBox Yes_Button leftmouseup', Delay)
                        Delay = Delay + 10
                        mq.cmdf('/timed %d /autoinventory', Delay)
                        Delay = Delay + 10
                    end
                end
            end
        end

        if sellOldAugs then
            if #removedAugs > 0 then
                if doDebug then
                    if not mq.TLO.Merchant.Open() then
                        mq.cmdf('/timed %d /echo \agDebug: \axOpening Montelio\'s merchant window', Delay)
                        Delay = Delay + 3
                    end
        
                    mq.cmdf('/timed %d /echo Selling %d old augs!\n', Delay, #removedAugs)
                    Delay = Delay + 15
        
                    for _, aug in ipairs(removedAugs) do
                        mq.cmdf('/timed %d \agDebug: \axSelling \ao"%s"', Delay, aug)
                        Delay = Delay + 10
                    end
                    print('Selling complete\n')
                else
                    if not mq.TLO.Merchant.Open() then
                        mq.cmdf('/timed %d /invoke ${Merchant.OpenWindow}', Delay)
                        Delay = Delay + 3
                    end

                    mq.cmdf('/timed %d /echo Selling %d old augs!', #removedAugs)
                    Delay = Delay + 15

                    for _, aug in ipairs(removedAugs) do
                        mq.cmdf('/timed %d /selectitem "=%s"', Delay, aug)
                        Delay = Delay + 10
                        mq.cmdf('timed %d /invoke ${Merchant.Sell}', Delay)
                        Delay = Delay + 10
                    end
                end
            end
        end

        -- Buy augs if needed
        if count > 0 then
            if doDebug then
                if cost < RoT then -- If you have enough remnants
                    -- Buy augs
                    if not mq.TLO.Merchant.Open() then
                        mq.cmdf('/timed %d /echo \agDebug: \axOpen Montelio\'s merchant window', Delay)
                        Delay = Delay + 5
                        mq.cmdf('/timed %d /echo \agDebug: \axPurchase \at%d \ao%s \ax\axfor \at%d \ax remnants', Delay, count, name, cost)
                        Delay = Delay + 5
                    end
                    
                    -- Need a for loop to buy all of the augs
                    for i=1, count do
                        mq.cmdf('/timed %d /echo \agDebug: \ax%d: Buy \ao%s', Delay, i, name)
                        Delay = Delay + 10
                    end
                    mq.cmdf('/timed %d /echo \agDebug: \axClosing Montelio\'s merchant window\n', Delay)
                    Delay = Delay + 15
                else
                    printf('\agDebug: \ao%s \axcosts \at%d \axand you have \at%d\ax! You need \ar%d \axmore!', name, cost, RoT, cost - RoT)
                    stop = true
                end
            else
                if cost < RoT then -- If you have enough remnants
                    -- Buy augs
                    if not mq.TLO.Merchant.Open() then
                        mq.cmdf('/timed %d /tar Montelio', Delay)
                        Delay = Delay + 5
                        mq.cmdf('/timed %d /invoke ${Merchant.OpenWindow}', Delay)
                        Delay = Delay + 5
                        mq.cmdf('/timed %d /echo Need to purchase %d %s for %d Remnants', Delay, count, name, cost)
                    end
                    Delay = Delay + 35
                    mq.cmdf('/timed %d /invoke ${Merchant.SelectItem[=%s]}', Delay, name)
                    Delay = Delay + 10

                    -- Need a for loop to buy all of the augs
                    for i=1, count do
                        mq.cmdf('/timed %d /invoke ${Merchant.Buy[%d]}', Delay, count)
                        Delay = Delay + 10
                    end
                    mq.cmdf('/timed %d /notify MerchantWnd MW_Done_Button leftmouseup', Delay)
                    Delay = Delay + 15
                else
                    printf('%s costs %d and you have %d! You need %d more!', name, cost, RoT, cost - RoT)
                    stop = true
                end
            end
        end


        -- Insert augs into gear
        if #gearForAugs >0 then
            mq.cmdf('/timed %d /echo Inserting %s into %d pieces of gear!', Delay, name, #gearForAugs)
            Delay = Delay + 5
    
            if doDebug then
                for _, gear in ipairs(gearForAugs) do
                    mq.cmdf('/timed %d /echo \agDebug: \axInsert aug into \ao%s', Delay, gear) -- Insert aug from cursor into gear
                    Delay = Delay + 10
                end
            else
                for _, gear in ipairs(gearForAugs) do
                    mq.cmdf('/timed %d /itemnotify "%s" leftmouseup', Delay, name) -- Pick up aug
                    Delay = Delay + 10
                    mq.cmdf('/timed %d /insertaug "%s"', Delay, gear) -- Insert aug from cursor into gear
                    Delay = Delay + 10
                end
            end
        end
        mq.cmdf('/timed %d /echo  ', Delay)
        Delay = Delay + 5
        mq.cmdf('/timed %d /echo \agComplete! \axInserted \at%d \ao%s \ax\axinto \at%d \axpieces of gear.', Delay, count, name, #gearForAugs)
    end
end

-- Update AltCurrency
local function updateRemnant()
    RoT = mq.TLO.Me.AltCurrency('Remnants of Tranquility')()
end

-- function to run the window
local function tbmAugs(open)
    -- We specify a default position/size in case there's no data in the .ini file.
    local main_viewport = imgui.GetMainViewport()
    imgui.SetNextWindowPos(main_viewport.WorkPos.x + 650, main_viewport.WorkPos.y + 20, ImGuiCond.FirstUseEver)

    -- change the window size
    imgui.SetNextWindowSize(550, 200, ImGuiCond.FirstUseEver)

    local show = false
    open, show = imgui.Begin("TBM Aug Swapper by MrInfernal", open)

    if not show then
        mq.unevent('remnant')
        ImGui.End()
        return open
    end

    ImGui.PushItemWidth(ImGui.GetFontSize() * -12);

    -- Main window element area --
    imgui.Text(mq.TLO.Me.Name() .. '.  Level: ' .. myLevel .. ' ' .. mq.TLO.Me.Class.Name())
    imgui.SameLine(350)
    if imgui.Button('Go to Vendors') then
        mq.cmd('/travelto "pohealth" @ nav locyxz 1326.60, 134.65, 66.35')
    end
    imgui.SameLine()
    if imgui.Button('Stop Nav') then
        mq.cmd('/nav stop')
    end
    imgui.Text('Remants of Tranquility: %d', RoT)
    imgui.SameLine(455)
    doDebug = imgui.Checkbox('Debug', doDebug)
    imgui.Text('\n')

    imgui.Text('Armor: ')
    imgui.SameLine()
    doVis = imgui.Checkbox('Visible', doVis)
    imgui.SameLine()
    doNonVis = imgui.Checkbox('Nonvisible', doNonVis)

    imgui.Text('Level     ')
    imgui.SameLine()
    augPrefixIndex = imgui.Combo(' ', augPrefixIndex, augPrefix, #augPrefix)
    imgui.SameLine()
    sellOldAugs = imgui.Checkbox(' Sell Augs', sellOldAugs)

    imgui.Text('Type 5: ')
    imgui.SameLine()
    type5Index = imgui.Combo('  ', type5Index, type5Suffix, #type5Suffix)
    imgui.SameLine()
    if imgui.Button(' Check') then
        checkAugs('armor', 5, augPrefixIndex, type5Index)
    end
    imgui.SameLine()
    if imgui.Button(' Buy') then
        doAugs('armor', 5, augPrefixIndex, type5Index)
    end

    imgui.Text('Type 9: ')
    imgui.SameLine()
    type9Index = imgui.Combo('   ', type9Index, type9Suffix, #type9Suffix)
    imgui.SameLine()
    if ImGui.Button("Check") then
        checkAugs('armor', 9, augPrefixIndex, type9Index)
    end
    imgui.SameLine()
    if ImGui.Button("Buy") then
        doAugs('armor', 9, augPrefixIndex, type9Index)
    end
    
    -- End of main window element area --
    -- Required for window elements
    imgui.Spacing()
    imgui.PopItemWidth()
    imgui.End()
    return open
end

mq.event('remnant', '#*#for #1# Remnants of Tranquility#*#', updateRemnant)

local openGUI = true

ImGui.Register('TBM Aug Swapper', function()
    openGUI = tbmAugs(openGUI)
end)

while openGUI do
    mq.doevents()
    mq.delay(1000) -- equivalent to '1s'
end